@@ -23,6 +23,10 @@
 
 /* GNU dd originally written by Paul Rubin, David MacKenzie, and Stuart Kemp. */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "dcfldd.h"
 #include "output.h"
 #include "full-write.h"
@@ -122,6 +126,7 @@ void outputlist_add(outputtype_t type, ...)
 
     ptr->next = NULL;
     ptr->type = type;
+    ptr->stream = NULL;
     ptr->diffwr = do_diffwr;
 
     switch (type) {
