@@ -78,18 +78,6 @@ extern int errno;
 
 #include "xstrtol.h"
 
-#ifndef strtol
-long int strtol ();
-#endif
-
-#ifndef strtoul
-unsigned long int strtoul ();
-#endif
-
-#ifndef strtoumax
-uintmax_t strtoumax ();
-#endif
-
 static int
 bkm_scale (__strtol_t *x, int scale_factor)
 {
